@@ -24,7 +24,7 @@ CGI::Mungo - Very simple CGI web framework
 
 =head1 DESCRIPTION
 
-All action subs are passed a L<CGI::Mungo> object as the only parameter, from this you should be able to reach
+All action subs are passed a <CGI::Mungo> object as the only parameter, from this you should be able to reach
 everything you need.
 
 =head1 METHODS
@@ -40,7 +40,7 @@ use CGI::Mungo::Response;
 use CGI::Mungo::Session;	#for session management
 use CGI::Mungo::Request;
 use Carp;
-our $VERSION = "1.3";
+our $VERSION = "1.1";
 #########################################################
 
 =pod
@@ -76,95 +76,27 @@ sub new{
 	}
 	return undef;
 }
-#########################################################
-
-=pod
-
-=item getResponse()
-
-	my $response = $m->getResponse();
-
-Returns an instance of the response plugin object, previously defined in the constructor options.
-See L<CGI::Mungo::Response> for more details.
-
-=cut
-
 ###########################################################
 sub getResponse{
 	my $self = shift;
 	return $self->{'_response'};
 }
-#########################################################
-
-=pod
-
-=item getSession()
-
-	my $session = $m->getSession();
-
-Returns an instance of the <CGI::Mungo::Session> object.
-
-=cut
-
 ###########################################################
 sub getSession{
 	my $self = shift;
 	return $self->{'_session'};
 }
-#########################################################
-
-=pod
-
-=item getRequest()
-
-	my $request = $m->getRequest();
-
-Returns an instance of the L<CGI::Mungo::Request> object.
-
-=cut
-
 ###########################################################
 sub getRequest{
 	my $self = shift;
 	return $self->{'_request'};
 }
-#########################################################
-
-=pod
-
-=item setActions()
-
-	my %actions = (
-		'default' => \&showMenu().
-		'list' => \%showList() 
-	)
-	$m->setActions(\%actions);
-
-Sets the actions of the web application using a hash reference. The names of the keys in the hash
-reference will match the value of the given "action" form field from the current request. Hash reference values
-can be references to subs or annoymous subs.
-
-=cut
-
 ###########################################################
 sub setActions{
 	my($self, $actions) = @_;
 	$self->{'_actions'} = $actions;
 	return 1;
 }
-#########################################################
-
-=pod
-
-=item getAction()
-
-	my $action = $m->getAction();
-
-Returns the curent action that the web application is performing. This is the current value of the "action"
-request form field.
-
-=cut
-
 ###########################################################
 sub getAction{
 	my $self = shift;
@@ -177,19 +109,6 @@ sub getAction{
 	$self->log("Using action: '$action'");
 	return $action;	
 }
-#########################################################
-
-=pod
-
-=item run()
-
-	$m->run();
-
-This methood is required for the web application to deal with the current request.
-It should be called after any setup is done.
-
-=cut
-
 ###########################################################
 sub run{	#run the code for the given action
 	my $self = shift;
@@ -211,24 +130,6 @@ sub run{	#run the code for the given action
 	$response->display();	#display the output to the browser
 	return 1;
 }
-#########################################################
-
-=pod
-
-=item getThisUrl()
-
-	my $url = $m->getThisUrl();
-
-Returns the full URL for the current script.
-
-=cut
-
-###########################################################
-sub getThisUrl{
-	my $self = shift;
-	my $url = $ENV{'SCRIPT_URI'};
-	return $url;
-}
 ###########################################################
 # Private methods
 ###########################################################
@@ -240,7 +141,7 @@ sub _init{	#things to do when this object is created
 	my $response = $self->getResponse();
 	my $session = $self->getSession();
 	my $existingSession = 0;
-	if($session->read()){	#check for an existing session
+	if($session->read()){	#cehck for an existing session
 		if($session->validate()){
 			$existingSession = 1;
 			$self->log("we have an existing session");
@@ -287,12 +188,6 @@ sub _getOption{
 
 =back
 
-=head1 Notes
-
-To change the session prefix characters use the following code at the top of your script:
-
-	$CGI::Mungo::Session::prefix = "ABC";
-
 =head1 Author
 
 MacGyveR <dumb@cpan.org>
@@ -306,6 +201,5 @@ Copyright (c) 2009 MacGyveR. All rights reserved.
 This library is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
 
 =cut
-
 ###########################################################
 return 1;
