@@ -9,19 +9,19 @@ Response Base - Base object for view plugins
 
 =head1 SYNOPSIS
 
-	use myResponse;
-	my $response = myResponse->new($mungo);
-	
-	package myResponse;
-	use base ("CGI::Mungo::Response::Base");
+use myResponse;
+my $response = myResponse->new($mungo);
+
+package myResponse;
+use base ("CGI::Mungo::Response::Base");
 
 =head1 DESCRIPTION
 
 This object should not be used directly, a new class should be created which inherits this one istead.
 
-All response plugins should override at least the display() method and they all a sub class of L<HTTP::Response>.
+All response plugins should override at least the display() method.
 
-The module L<CGI::Mungo::Response> will load the specified response plugin on script startup.
+The module CGI::Mungo::Response will load the specified respomse plugin on script startup.
 
 =head1 METHODS
 
@@ -32,17 +32,29 @@ The module L<CGI::Mungo::Response> will load the specified response plugin on sc
 use strict;
 use warnings;
 use Carp;
-use base qw(HTTP::Response CGI::Mungo::Base);
+use base ("HTTP::Response");
 #########################################################
 sub new{
 	my($class, $mungo) = @_;
 	my $self = $class->SUPER::new(200, "OK");	#we dont care about the code or msg as they get removed later
 	$self->{'_mungo'} = $mungo;	#so we can access the mungo object FIXME
+	$self->{'_error'} = undef;
 	$self->{'_displayedHeader'} = 0;	#flag set on first output
 	bless $self, $class;
 	return $self;
 }
 #########################################################
+sub setError{
+	my($self, $error) = @_;
+	$self->{'_error'} = $error;
+	return 1;
+}
+#########################################################
+sub getError{
+	my $self = shift;
+	return $self->{'_error'};
+}
+#########################################################
 sub getMungo{
 	my $self = shift;
 	return $self->{'_mungo'};
