@@ -1,31 +1,9 @@
 #response object
 package CGI::Mungo::Response::SimpleTemplate;
-
-=pod
-
-=head1 NAME
-
-Response SimpleTemplate - Simple templating view plugin
-
-=head1 SYNOPSIS
-
-	my $response = $mungo->getResponse();
-	$response->setTemplateVar("hello", $something);
-
-=head1 DESCRIPTION
-
-This view plugin allows you to read a template file and replace placholders with scalar variables.
-
-=head1 METHODS
-
-=over 4
-
-=cut
-
 use strict;
 use warnings;
-use base qw(CGI::Mungo::Response::Base CGI::Mungo::Log);
-our $templateLoc = "../root/templates";	#where the templates are stored
+use base ("CGI::Mungo::Response::Base");
+our $templateLoc = "/var/httpd/lowercall/cgi-shl/data";	#where the templates are stored
 #########################################################
 sub new{
 	my($class, $mungo) = @_;
@@ -95,12 +73,9 @@ sub _getContent{
 	if(!$self->getError()){
 		$content = $self->_parseFile($self->getTemplate());
 	}
-	if($self->getError()){	#_parseFile may have errored
+	else{
 		$self->setTemplateVar('message', $self->getError());
 		$content = $self->_parseFile("genericerror");
-		if(!$content){	#_parseFile may have errored again
-			$self->log($self->getError());	#just log it so we have a record of this
-		}
 	}
 	return $content;
 }
@@ -112,7 +87,7 @@ sub _readFile{
 		while(my $line = <CONT>){
 			$content .= $line
 		}
-		close(CONT);
+		close(CONT);;
 	}
 	else{
 		$self->setError("Cant open file: $file: $!");
@@ -122,7 +97,7 @@ sub _readFile{
 ##################################################################################
 sub _parseFile{	#this returns the contents of a page
 	my($self, $page) = @_;
-	my $contents = $self->_readFile($self->_getTemplateLocation() . '/' . $page . ".html");
+	my $contents = $self->_readFile($templateLoc . '/' . $page . ".html");
 	if($contents){
 		$contents =~ s/\[% INCLUDE ([a-z\-\/]+); %\]/$self->_parseFile('includes\/' . $1)/eg;	#include any component files first
 		$contents =~ s/<!--self-->/$ENV{'SCRIPT_NAME'}/g;
@@ -142,52 +117,5 @@ sub _getTemplateNameForAction{
 	my $name = $script . "-" . $action;
 	return $name;
 }
-#########################################################
-sub _getTemplateLocation{
-	return $templateLoc;
-}
-##########################################################
-sub _getHash{
-	my($self, $name) = @_;
-	if($name eq "message" && $self->getError()) {	#need to print the error message here
-		return $self->getError();
-	}
-	if(defined($self->getTemplateVar($name))){
-		return $self->getTemplateVar($name);
-	}
-	else{
-		$self->log("$name is undefined");
-		return "";
-	}
-}
-##############################################################
-
-=pod
-
-=back
-
-=head1 Notes
-
-If an error occurs a template called "genericerror.html" will be used instead of the specified template.
-Please make sure you have this file, there is an example of this in the "root/templates" directory of this module.
-
-To change the template location use the following code at the top of your script:
-
-	$CGI::Mungo::Response::SimpleTemplate::templateLoc = "../root";
-
-=head1 Author
-
-MacGyveR <dumb@cpan.org>
-
-Development questions, bug reports, and patches are welcome to the above address
-
-=head1 Copyright
-
-Copyright (c) 2009 MacGyveR. All rights reserved.
-
-This library is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
-
-=cut
-
 #########################################################
 return 1;
\ No newline at end of file
